@@ -25,7 +25,6 @@ from unittest import mock
 from oslo_log import formatters
 from oslo_log import log as logging
 from oslotest import base
-import six
 import testtools
 
 from oslo_privsep import capabilities
@@ -75,36 +74,35 @@ def logme(level, msg, exc_info=False):
 
 class LogRecorder(pylogging.Formatter):
     def __init__(self, logs, *args, **kwargs):
-        if sys.version_info >= (3, 8):
-            kwargs['validate'] = False
-        super(LogRecorder, self).__init__(*args, **kwargs)
+        kwargs['validate'] = False
+        super().__init__(*args, **kwargs)
         self.logs = logs
 
     def format(self, record):
         self.logs.append(copy.deepcopy(record))
-        return super(LogRecorder, self).format(record)
+        return super().format(record)
 
 
 @testtools.skipIf(platform.system() != 'Linux',
                   'works only on Linux platform.')
 class LogTest(testctx.TestContextTestCase):
     def setUp(self):
-        super(LogTest, self).setUp()
+        super().setUp()
 
     def test_priv_loglevel(self):
         logger = self.useFixture(fixtures.FakeLogger(
             level=logging.INFO))
 
         # These write to the log on the priv side
-        logme(logging.DEBUG, u'test@DEBUG')
-        logme(logging.WARN, u'test@WARN')
+        logme(logging.DEBUG, 'test@DEBUG')
+        logme(logging.WARN, 'test@WARN')
 
         time.sleep(0.1)  # Hack to give logging thread a chance to run
 
         # logger.output is the resulting log on the unpriv side.
         # This should have been filtered based on (unpriv) loglevel.
-        self.assertNotIn(u'test@DEBUG', logger.output)
-        self.assertIn(u'test@WARN', logger.output)
+        self.assertNotIn('test@DEBUG', logger.output)
+        self.assertIn('test@WARN', logger.output)
 
     def test_record_data(self):
         logs = []
@@ -115,19 +113,19 @@ class LogTest(testctx.TestContextTestCase):
             # class/function, not an instance :(
             formatter=functools.partial(LogRecorder, logs)))
 
-        logme(logging.WARN, u'test with exc', exc_info=True)
+        logme(logging.WARN, 'test with exc', exc_info=True)
 
         time.sleep(0.1)  # Hack to give logging thread a chance to run
 
         self.assertEqual(1, len(logs))
 
         record = logs[0]
-        self.assertIn(u'test with exc', record.getMessage())
+        self.assertIn('test with exc', record.getMessage())
         self.assertIsNone(record.exc_info)
-        self.assertIn(u'TestException: with arg', record.exc_text)
+        self.assertIn('TestException: with arg', record.exc_text)
         self.assertEqual('PrivContext(cfg_section=privsep)',
                          record.processName)
-        self.assertIn(u'test_daemon.py', record.exc_text)
+        self.assertIn('test_daemon.py', record.exc_text)
         self.assertEqual(logging.WARN, record.levelno)
         self.assertEqual('logme', record.funcName)
 
@@ -140,7 +138,7 @@ class LogTest(testctx.TestContextTestCase):
             # class/function, not an instance :(
             formatter=functools.partial(LogRecorder, logs)))
 
-        logme(logging.WARN, u'test with exc', exc_info=True)
+        logme(logging.WARN, 'test with exc', exc_info=True)
 
         time.sleep(0.1)  # Hack to give logging thread a chance to run
 
@@ -168,6 +166,11 @@ class DaemonTest(base.BaseTestCase):
         channel = mock.NonCallableMock()
         context = get_fake_context()
 
+        manager = mock.Mock()
+        manager.attach_mock(mock_setuid, "setuid")
+        manager.attach_mock(mock_setgid, "setgid")
+        expected_calls = [mock.call.setgid(84), mock.call.setuid(42)]
+
         d = daemon.Daemon(channel, context)
         d._drop_privs()
 
@@ -175,13 +178,15 @@ class DaemonTest(base.BaseTestCase):
         mock_setgid.assert_called_once_with(84)
         mock_setgroups.assert_called_once_with([])
 
+        assert manager.mock_calls == expected_calls
+
         self.assertCountEqual(
             [mock.call(True), mock.call(False)],
             mock_keepcaps.mock_calls)
 
         mock_dropcaps.assert_called_once_with(
-            set((capabilities.CAP_SYS_ADMIN, capabilities.CAP_NET_ADMIN)),
-            set((capabilities.CAP_SYS_ADMIN, capabilities.CAP_NET_ADMIN)),
+            {capabilities.CAP_SYS_ADMIN, capabilities.CAP_NET_ADMIN},
+            {capabilities.CAP_SYS_ADMIN, capabilities.CAP_NET_ADMIN},
             [])
 
 
@@ -198,17 +203,17 @@ class WithContextTest(testctx.TestContextTestCase):
 class ClientChannelTestCase(base.BaseTestCase):
 
     DICT = {
-        'string_1': ('tuple_1', six.b('tuple_2')),
-        six.b('byte_1'): ['list_1', 'list_2'],
+        'string_1': ('tuple_1', b'tuple_2'),
+        b'byte_1': ['list_1', 'list_2'],
     }
 
     EXPECTED = {
-        'string_1': ('tuple_1', six.b('tuple_2')),
+        'string_1': ('tuple_1', b'tuple_2'),
         'byte_1': ['list_1', 'list_2'],
     }
 
     def setUp(self):
-        super(ClientChannelTestCase, self).setUp()
+        super().setUp()
         context = get_fake_context()
         with mock.patch.object(comm.ClientChannel, '__init__'), \
                 mock.patch.object(daemon._ClientChannel, 'exchange_ping'):
